package xdg

const (
	// DesktopDirEnv is the name of the environment variable holding a user desktop directory path.
	DesktopDirEnv = "XDG_DESKTOP_DIR"
	// DownloadDirEnv is the name of the environment variable holding a user download directory path.
	DownloadDirEnv = "XDG_DOWNLOAD_DIR"
	// DocumentsDirEnv is the name of the environment variable holding a user documents directory path.
	DocumentsDirEnv = "XDG_DOCUMENTS_DIR"
	// MusicDirEnv is the name of the environment variable holding a user music directory path.
	MusicDirEnv = "XDG_MUSIC_DIR"
	// PicturesDirEnv is the name of the environment variable holding a user pictures directory path.
	PicturesDirEnv = "XDG_PICTURES_DIR"
	// VideosDirEnv is the name of the environment variable holding a user videos directory path.
	VideosDirEnv = "XDG_VIDEOS_DIR"
	// TemplatesDirEnv is the name of the environment variable holding a user templates directory path.
	TemplatesDirEnv = "XDG_TEMPLATES_DIR"
	// PublicShareDirEnv is the name of the environment variable holding a user public share directory path.
	PublicShareDirEnv = "XDG_PUBLICSHARE_DIR"
)
